{ config, inputs, lib, pkgs, ... }:

let
  inherit (builtins) toString;
  inherit (lib.modules) mkDefault;
  inherit (lib.my) mapModulesRec';
in {
  imports =
    [ 
      inputs.home-manager.nixosModules.home-manager
    ]
    ++ (mapModulesRec' (toString ./modules) import);

  nix = {
    package = pkgs.nix;

    # flake registry and nix path pinning
    nixPath = [ "nixpkgs=${inputs.nixpkgs}" ];
    registry.nixpkgs.flake = inputs.nixpkgs;
  
  	settings = {
      experimental-features = [ "nix-command" "flakes" ];
      auto-optimise-store = true;
      keep-outputs = true;
      keep-derivations = true;
      substituters = [ 
        "https://nix-community.cachix.org" 
      ];
      trusted-public-keys = [
      	"nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
      ];
  	};
  };

  environment.systemPackages = with pkgs; [
    unrar unzip
    curl wget
    # nixos-rebuild w/ flakes does not work without git
    # do not remove this
    # nix is awesome
    git
  ];

  time.timeZone = mkDefault "America/Los_Angeles";

  i18n.defaultLocale = mkDefault "en_US.UTF-8";

  system.stateVersion = mkDefault "23.11";
}
